@@ -136,10 +136,12 @@ void print_params(drivedesc_t *drivedesc,
 	if(level >= LEV_EXPL || (ft->track != 80 && ft->track != 40))
 		print("cyl=%d", ft->track);
 
-#ifdef FD_SWAPSIDES
 	if(ft->stretch & FD_SWAPSIDES)
 		print("swapsides",0);			
-#endif
+
+	if(ft->stretch & FD_ZEROBASED)
+		print("zerobased",0);			
+
 
 	if(ft->rate & FD_2M)
 		print("2M",0);
